# RMextract
extract TEC, vTEC, Earthmagnetic field and Rotation Measures from GPS and WMM data for radio interferometry observations 

Please cite as: Mevius, M. (2018) RMextract, Astrophysics Source Code Library, record [ascl:1806.024]

WMM model data: 
NCEI Geomagnetic Modeling Team and British Geological Survey. 2019. World Magnetic Model 2020. NOAA National Centers for Environmental Information. doi: 10.25921/11v3-da71, 2020

IRI model:
D. Bilitza, IRI the International Standard for the Ionosphere, Adv. Radio Sci., 16, 1-11, https://doi.org/10.5194/ars-16-1-2018, 2018. 

IRIPlas model:
T. Gulyaeva and D. Bilitza, "Towards ISO standard earth ionosphere and plasmasphere model," in New Developments in the Standard Model R. Larsen, Ed. Hauppauge, New York: NOVA, 2012, pp. 1-48.
